@@ -16,7 +16,7 @@
  * and other information needed for compilation.
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_typepass_cxx[] = "$Id: typepass.cxx 13030 2012-05-01 18:44:22Z wsfulton $";
+char cvsroot_typepass_cxx[] = "$Id: typepass.cxx 13507 2012-08-04 20:25:43Z wsfulton $";
 
 #include "swigmod.h"
 #include "cparse.h"
@@ -1159,6 +1159,11 @@ class TypePass:private Dispatcher {
 	  SwigType_typedef_using(uname);
 	} else if (Strcmp(ntype, "enum") == 0) {
 	  SwigType_typedef_using(Getattr(n, "uname"));
+	} else if (Strcmp(ntype, "template") == 0) {
+	  /*
+	  Printf(stdout, "usingDeclaration template %s --- %s\n", Getattr(n, "name"), Getattr(n, "uname"));
+	  SwigType_typedef_using(Getattr(n, "uname"));
+	  */
 	}
       }
     }
