@@ -129,85 +129,82 @@ extern "C" {
   extern SwigType *SwigType_add_function(SwigType *t, ParmList *parms);
   extern SwigType *SwigType_add_template(SwigType *t, ParmList *parms);
   extern SwigType *SwigType_pop_function(SwigType *t);
-  extern ParmList *SwigType_function_parms(SwigType *t, Node *file_line_node);
+  extern ParmList *SwigType_function_parms(const SwigType *t, Node *file_line_node);
   extern List *SwigType_split(const SwigType *t);
   extern String *SwigType_pop(SwigType *t);
-  extern void SwigType_push(SwigType *t, SwigType *s);
+  extern void SwigType_push(SwigType *t, String *s);
   extern List *SwigType_parmlist(const SwigType *p);
-  extern String *SwigType_parm(String *p);
-  extern String *SwigType_str(SwigType *s, const_String_or_char_ptr id);
-  extern String *SwigType_lstr(SwigType *s, const_String_or_char_ptr id);
-  extern String *SwigType_rcaststr(SwigType *s, const_String_or_char_ptr id);
-  extern String *SwigType_lcaststr(SwigType *s, const_String_or_char_ptr id);
-  extern String *SwigType_manglestr(SwigType *t);
-  extern SwigType *SwigType_ltype(SwigType *t);
-  extern int SwigType_ispointer(SwigType *t);
-  extern int SwigType_ispointer_return(SwigType *t);
-  extern int SwigType_isfunctionpointer(SwigType *t);
-  extern int SwigType_ismemberpointer(SwigType *t);
-  extern int SwigType_isreference(SwigType *t);
-  extern int SwigType_isreference_return(SwigType *t);
-  extern int SwigType_isarray(SwigType *t);
-  extern int SwigType_prefix_is_simple_1D_array(SwigType *t);
-  extern int SwigType_isfunction(SwigType *t);
-  extern int SwigType_isqualifier(SwigType *t);
-  extern int SwigType_isconst(SwigType *t);
-  extern int SwigType_issimple(SwigType *t);
-  extern int SwigType_ismutable(SwigType *t);
+  extern String *SwigType_parm(const SwigType *p);
+  extern String *SwigType_str(const SwigType *s, const_String_or_char_ptr id);
+  extern String *SwigType_lstr(const SwigType *s, const_String_or_char_ptr id);
+  extern String *SwigType_rcaststr(const SwigType *s, const_String_or_char_ptr id);
+  extern String *SwigType_lcaststr(const SwigType *s, const_String_or_char_ptr id);
+  extern String *SwigType_manglestr(const SwigType *t);
+  extern SwigType *SwigType_ltype(const SwigType *t);
+  extern int SwigType_ispointer(const SwigType *t);
+  extern int SwigType_ispointer_return(const SwigType *t);
+  extern int SwigType_isfunctionpointer(const SwigType *t);
+  extern int SwigType_ismemberpointer(const SwigType *t);
+  extern int SwigType_isreference(const SwigType *t);
+  extern int SwigType_isreference_return(const SwigType *t);
+  extern int SwigType_isarray(const SwigType *t);
+  extern int SwigType_prefix_is_simple_1D_array(const SwigType *t);
+  extern int SwigType_isfunction(const SwigType *t);
+  extern int SwigType_isqualifier(const SwigType *t);
+  extern int SwigType_isconst(const SwigType *t);
+  extern int SwigType_issimple(const SwigType *t);
+  extern int SwigType_ismutable(const SwigType *t);
   extern int SwigType_isvarargs(const SwigType *t);
   extern int SwigType_istemplate(const SwigType *t);
-  extern int SwigType_isenum(SwigType *t);
-  extern int SwigType_check_decl(SwigType *t, const_String_or_char_ptr decl);
-  extern SwigType *SwigType_strip_qualifiers(SwigType *t);
-  extern SwigType *SwigType_strip_single_qualifier(SwigType *t);
+  extern int SwigType_isenum(const SwigType *t);
+  extern int SwigType_check_decl(const SwigType *t, const_String_or_char_ptr decl);
+  extern SwigType *SwigType_strip_qualifiers(const SwigType *t);
+  extern SwigType *SwigType_strip_single_qualifier(const SwigType *t);
   extern SwigType *SwigType_functionpointer_decompose(SwigType *t);
   extern String *SwigType_base(const SwigType *t);
   extern String *SwigType_namestr(const SwigType *t);
   extern String *SwigType_templateprefix(const SwigType *t);
   extern String *SwigType_templatesuffix(const SwigType *t);
   extern String *SwigType_istemplate_templateprefix(const SwigType *t);
+  extern String *SwigType_istemplate_only_templateprefix(const SwigType *t);
   extern String *SwigType_templateargs(const SwigType *t);
   extern String *SwigType_prefix(const SwigType *t);
-  extern int SwigType_array_ndim(SwigType *t);
-  extern String *SwigType_array_getdim(SwigType *t, int n);
+  extern int SwigType_array_ndim(const SwigType *t);
+  extern String *SwigType_array_getdim(const SwigType *t, int n);
   extern void SwigType_array_setdim(SwigType *t, int n, const_String_or_char_ptr rep);
-  extern SwigType *SwigType_array_type(SwigType *t);
-  extern String *SwigType_default(SwigType *t);
-  extern SwigType *SwigType_default_create(SwigType *ty);
-  extern SwigType *SwigType_default_deduce(SwigType *t);
+  extern SwigType *SwigType_array_type(const SwigType *t);
+  extern SwigType *SwigType_default_create(const SwigType *ty);
+  extern SwigType *SwigType_default_deduce(const SwigType *t);
   extern void SwigType_typename_replace(SwigType *t, String *pat, String *rep);
   extern SwigType *SwigType_remove_global_scope_prefix(const SwigType *t);
-  extern SwigType *SwigType_alttype(SwigType *t, int ltmap);
-
-  extern void SwigType_template_defargs(Parm *parms, Parm *targs, Symtab *tscope, Symtab *tsdecl);
-  extern SwigType *SwigType_template_deftype(const SwigType *type, Symtab *tscope);
+  extern SwigType *SwigType_alttype(const SwigType *t, int ltmap);
 
 /* --- Type-system managment --- */
   extern void SwigType_typesystem_init(void);
-  extern int SwigType_typedef(SwigType *type, const_String_or_char_ptr name);
+  extern int SwigType_typedef(const SwigType *type, const_String_or_char_ptr name);
   extern int SwigType_typedef_class(const_String_or_char_ptr name);
   extern int SwigType_typedef_using(const_String_or_char_ptr qname);
   extern void SwigType_inherit(String *subclass, String *baseclass, String *cast, String *conversioncode);
-  extern int SwigType_issubtype(SwigType *subtype, SwigType *basetype);
+  extern int SwigType_issubtype(const SwigType *subtype, const SwigType *basetype);
   extern void SwigType_scope_alias(String *aliasname, Typetab *t);
   extern void SwigType_using_scope(Typetab *t);
   extern void SwigType_new_scope(const_String_or_char_ptr name);
   extern void SwigType_inherit_scope(Typetab *scope);
   extern Typetab *SwigType_pop_scope(void);
   extern Typetab *SwigType_set_scope(Typetab *h);
-  extern void SwigType_print_scope(Typetab *t);
+  extern void SwigType_print_scope(void);
   extern SwigType *SwigType_typedef_resolve(const SwigType *t);
-  extern SwigType *SwigType_typedef_resolve_all(SwigType *t);
-  extern SwigType *SwigType_typedef_qualified(SwigType *t);
-  extern int SwigType_istypedef(SwigType *t);
-  extern int SwigType_isclass(SwigType *t);
+  extern SwigType *SwigType_typedef_resolve_all(const SwigType *t);
+  extern SwigType *SwigType_typedef_qualified(const SwigType *t);
+  extern int SwigType_istypedef(const SwigType *t);
+  extern int SwigType_isclass(const SwigType *t);
   extern void SwigType_attach_symtab(Symtab *syms);
-  extern void SwigType_remember(SwigType *t);
-  extern void SwigType_remember_clientdata(SwigType *t, const_String_or_char_ptr clientdata);
+  extern void SwigType_remember(const SwigType *t);
+  extern void SwigType_remember_clientdata(const SwigType *t, const_String_or_char_ptr clientdata);
   extern void SwigType_remember_mangleddata(String *mangled, const_String_or_char_ptr clientdata);
-  extern void (*SwigType_remember_trace(void (*tf) (SwigType *, String *, String *))) (SwigType *, String *, String *);
+  extern void (*SwigType_remember_trace(void (*tf) (const SwigType *, String *, String *))) (const SwigType *, String *, String *);
   extern void SwigType_emit_type_table(File *f_headers, File *f_table);
-  extern int SwigType_type(SwigType *t);
+  extern int SwigType_type(const SwigType *t);
 
 /* --- Symbol table module --- */
 
@@ -230,6 +227,7 @@ extern "C" {
   extern void Swig_symbol_cadd(const_String_or_char_ptr symname, Node *node);
   extern Node *Swig_symbol_clookup(const_String_or_char_ptr symname, Symtab *tab);
   extern Node *Swig_symbol_clookup_check(const_String_or_char_ptr symname, Symtab *tab, int (*check) (Node *));
+  extern Node *Swig_symbol_clookup_no_inherit(const_String_or_char_ptr name, Symtab *n);
   extern Symtab *Swig_symbol_cscope(const_String_or_char_ptr symname, Symtab *tab);
   extern Node *Swig_symbol_clookup_local(const_String_or_char_ptr symname, Symtab *tab);
   extern Node *Swig_symbol_clookup_local_check(const_String_or_char_ptr symname, Symtab *tab, int (*check) (Node *));
@@ -240,7 +238,7 @@ extern "C" {
   extern void Swig_symbol_inherit(Symtab *tab);
   extern SwigType *Swig_symbol_type_qualify(const SwigType *ty, Symtab *tab);
   extern String *Swig_symbol_string_qualify(String *s, Symtab *tab);
-  extern SwigType *Swig_symbol_typedef_reduce(SwigType *ty, Symtab *tab);
+  extern SwigType *Swig_symbol_typedef_reduce(const SwigType *ty, Symtab *tab);
 
   extern ParmList *Swig_symbol_template_defargs(Parm *parms, Parm *targs, Symtab *tscope, Symtab *tsdecl);
   extern SwigType *Swig_symbol_template_deftype(const SwigType *type, Symtab *tscope);
@@ -286,6 +284,7 @@ extern int        ParmList_is_compactdefargs(ParmList *p);
 
   extern String *Swig_name_make(Node *n, String *prefix, const_String_or_char_ptr cname, SwigType *decl, String *oldname);
   extern String *Swig_name_warning(Node *n, String *prefix, String *name, SwigType *decl);
+  extern String *Swig_name_str(Node *n);
   extern String *Swig_name_decl(Node *n);
   extern String *Swig_name_fulldecl(Node *n);
 
@@ -337,6 +336,8 @@ extern int        ParmList_is_compactdefargs(ParmList *p);
   extern String *Swig_stringify_with_location(DOH *object);
 
 /* --- C Wrappers --- */
+  extern void Swig_cresult_name_set(const char *new_name);
+  extern const char *Swig_cresult_name(void);
   extern String *Swig_cparm_name(Parm *p, int i);
   extern String *Swig_wrapped_var_type(SwigType *t, int varcref);
   extern int Swig_cargs(Wrapper *w, ParmList *l);
@@ -388,6 +389,7 @@ extern int        ParmList_is_compactdefargs(ParmList *p);
   extern void Swig_typemap_debug(void);
   extern void Swig_typemap_search_debug_set(void);
   extern void Swig_typemap_used_debug_set(void);
+  extern void Swig_typemap_register_debug_set(void);
 
   extern String *Swig_typemap_lookup(const_String_or_char_ptr tmap_method, Node *n, const_String_or_char_ptr lname, Wrapper *f);
   extern String *Swig_typemap_lookup_out(const_String_or_char_ptr tmap_method, Node *n, const_String_or_char_ptr lname, Wrapper *f, String *actioncode);
